# coding: utf-8

"""
    Files

    Upload and manage files.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.files.api_client import ApiClient
from hubspot.files.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class FilesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive(self, file_id, **kwargs):  # noqa: E501
        """Delete file by ID  # noqa: E501

        Delete a file by ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive(file_id, async_req=True)
        >>> result = thread.get()

        :param file_id: FileId to delete (required)
        :type file_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_with_http_info(file_id, **kwargs)  # noqa: E501

    def archive_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Delete file by ID  # noqa: E501

        Delete a file by ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param file_id: FileId to delete (required)
        :type file_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["file_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and local_var_params.get("file_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `archive`")  # noqa: E501

        if self.api_client.client_side_validation and "file_id" in local_var_params and not re.search(r"\d+", local_var_params["file_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `file_id` when calling `archive`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "file_id" in local_var_params:
            path_params["fileId"] = local_var_params["file_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/files/v3/files/{fileId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def check_import(self, task_id, **kwargs):  # noqa: E501
        """Check import status  # noqa: E501

        Check the status of requested import.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.check_import(task_id, async_req=True)
        >>> result = thread.get()

        :param task_id: Import by URL task ID (required)
        :type task_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: FileActionResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.check_import_with_http_info(task_id, **kwargs)  # noqa: E501

    def check_import_with_http_info(self, task_id, **kwargs):  # noqa: E501
        """Check import status  # noqa: E501

        Check the status of requested import.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.check_import_with_http_info(task_id, async_req=True)
        >>> result = thread.get()

        :param task_id: Import by URL task ID (required)
        :type task_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(FileActionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["task_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method check_import" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'task_id' is set
        if self.api_client.client_side_validation and local_var_params.get("task_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `task_id` when calling `check_import`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "task_id" in local_var_params:
            path_params["taskId"] = local_var_params["task_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "FileActionResponse",
        }

        return self.api_client.call_api(
            "/files/v3/files/import-from-url/async/tasks/{taskId}/status",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def delete(self, file_id, **kwargs):  # noqa: E501
        """GDPR-delete file  # noqa: E501

        Delete a file in accordance with GDPR regulations.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete(file_id, async_req=True)
        >>> result = thread.get()

        :param file_id: ID of file to GDPR delete (required)
        :type file_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.delete_with_http_info(file_id, **kwargs)  # noqa: E501

    def delete_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """GDPR-delete file  # noqa: E501

        Delete a file in accordance with GDPR regulations.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param file_id: ID of file to GDPR delete (required)
        :type file_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["file_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method delete" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and local_var_params.get("file_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `delete`")  # noqa: E501

        if self.api_client.client_side_validation and "file_id" in local_var_params and not re.search(r"\d+", local_var_params["file_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `file_id` when calling `delete`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "file_id" in local_var_params:
            path_params["fileId"] = local_var_params["file_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/files/v3/files/{fileId}/gdpr-delete",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def do_search(self, **kwargs):  # noqa: E501
        """Search files  # noqa: E501

        Search through files in the file manager. Does not display hidden or archived files.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.do_search(async_req=True)
        >>> result = thread.get()

        :param properties: A list of file properties to return.
        :type properties: list[str]
        :param after: Offset search results by this value. The default offset is 0 and the maximum offset of items for a given search is 10,000. Narrow your search down if you are reaching this limit.
        :type after: str
        :param before:
        :type before: str
        :param limit: Number of items to return. Default limit is 10, maximum limit is 100.
        :type limit: int
        :param sort: Sort files by a given field.
        :type sort: list[str]
        :param ids: Search by a list of file IDs.
        :type ids: list[int]
        :param id_lte:
        :type id_lte: int
        :param id_gte:
        :type id_gte: int
        :param created_at: Search files by time of creation.
        :type created_at: datetime
        :param created_at_lte: Search files by less than or equal to time of creation. Can be used with `createdAtGte` to create a range.
        :type created_at_lte: datetime
        :param created_at_gte: Search files by greater than or equal to time of creation. Can be used with `createdAtLte` to create a range.
        :type created_at_gte: datetime
        :param updated_at: Search files by time of latest updated.
        :type updated_at: datetime
        :param updated_at_lte: Search files by less than or equal to time of latest update. Can be used with `updatedAtGte` to create a range.
        :type updated_at_lte: datetime
        :param updated_at_gte: Search files by greater than or equal to time of latest update. Can be used with `updatedAtLte` to create a range.
        :type updated_at_gte: datetime
        :param name: Search for files containing the given name.
        :type name: str
        :param path: Search files by path.
        :type path: str
        :param parent_folder_ids: Search files within given `folderId`.
        :type parent_folder_ids: list[int]
        :param size: Search files by exact file size in bytes.
        :type size: int
        :param size_lte: Search files by less than or equal to file size. Can be used with `sizeGte` to create a range.
        :type size_lte: int
        :param size_gte: Search files by greater than or equal to file size. Can be used with `sizeLte` to create a range.
        :type size_gte: int
        :param height: Search files by height of image or video.
        :type height: int
        :param height_lte: Search files by less than or equal to height of image or video. Can be used with `heightGte` to create a range.
        :type height_lte: int
        :param height_gte: Search files by greater than or equal to height of image or video. Can be used with `heightLte` to create a range.
        :type height_gte: int
        :param width: Search files by width of image or video.
        :type width: int
        :param width_lte: Search files by less than or equal to width of image or video. Can be used with `widthGte` to create a range.
        :type width_lte: int
        :param width_gte: Search files by greater than or equal to width of image or video. Can be used with `widthLte` to create a range.
        :type width_gte: int
        :param encoding: Search files by specified encoding.
        :type encoding: str
        :param type: Filter by provided file type.
        :type type: str
        :param extension: Search files by given extension.
        :type extension: str
        :param url: Search by file URL.
        :type url: str
        :param is_usable_in_content: If `true`, shows files that have been marked to be used in new content. If `false`, shows files that should not be used in new content.
        :type is_usable_in_content: bool
        :param allows_anonymous_access: Search files by access. If `true`, will show only public files. If `false`, will show only private files.
        :type allows_anonymous_access: bool
        :param file_md5: Search files by a specific md5 hash.
        :type file_md5: str
        :param expires_at: Search files by exact expires time. Time must be epoch time in milliseconds.
        :type expires_at: datetime
        :param expires_at_lte: Search files by less than or equal to expires time. Can be used with `expiresAtGte` to create a range.
        :type expires_at_lte: datetime
        :param expires_at_gte: Search files by greater than or equal to expires time. Can be used with `expiresAtLte` to create a range.
        :type expires_at_gte: datetime
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CollectionResponseFile
        """
        kwargs["_return_http_data_only"] = True
        return self.do_search_with_http_info(**kwargs)  # noqa: E501

    def do_search_with_http_info(self, **kwargs):  # noqa: E501
        """Search files  # noqa: E501

        Search through files in the file manager. Does not display hidden or archived files.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.do_search_with_http_info(async_req=True)
        >>> result = thread.get()

        :param properties: A list of file properties to return.
        :type properties: list[str]
        :param after: Offset search results by this value. The default offset is 0 and the maximum offset of items for a given search is 10,000. Narrow your search down if you are reaching this limit.
        :type after: str
        :param before:
        :type before: str
        :param limit: Number of items to return. Default limit is 10, maximum limit is 100.
        :type limit: int
        :param sort: Sort files by a given field.
        :type sort: list[str]
        :param ids: Search by a list of file IDs.
        :type ids: list[int]
        :param id_lte:
        :type id_lte: int
        :param id_gte:
        :type id_gte: int
        :param created_at: Search files by time of creation.
        :type created_at: datetime
        :param created_at_lte: Search files by less than or equal to time of creation. Can be used with `createdAtGte` to create a range.
        :type created_at_lte: datetime
        :param created_at_gte: Search files by greater than or equal to time of creation. Can be used with `createdAtLte` to create a range.
        :type created_at_gte: datetime
        :param updated_at: Search files by time of latest updated.
        :type updated_at: datetime
        :param updated_at_lte: Search files by less than or equal to time of latest update. Can be used with `updatedAtGte` to create a range.
        :type updated_at_lte: datetime
        :param updated_at_gte: Search files by greater than or equal to time of latest update. Can be used with `updatedAtLte` to create a range.
        :type updated_at_gte: datetime
        :param name: Search for files containing the given name.
        :type name: str
        :param path: Search files by path.
        :type path: str
        :param parent_folder_ids: Search files within given `folderId`.
        :type parent_folder_ids: list[int]
        :param size: Search files by exact file size in bytes.
        :type size: int
        :param size_lte: Search files by less than or equal to file size. Can be used with `sizeGte` to create a range.
        :type size_lte: int
        :param size_gte: Search files by greater than or equal to file size. Can be used with `sizeLte` to create a range.
        :type size_gte: int
        :param height: Search files by height of image or video.
        :type height: int
        :param height_lte: Search files by less than or equal to height of image or video. Can be used with `heightGte` to create a range.
        :type height_lte: int
        :param height_gte: Search files by greater than or equal to height of image or video. Can be used with `heightLte` to create a range.
        :type height_gte: int
        :param width: Search files by width of image or video.
        :type width: int
        :param width_lte: Search files by less than or equal to width of image or video. Can be used with `widthGte` to create a range.
        :type width_lte: int
        :param width_gte: Search files by greater than or equal to width of image or video. Can be used with `widthLte` to create a range.
        :type width_gte: int
        :param encoding: Search files by specified encoding.
        :type encoding: str
        :param type: Filter by provided file type.
        :type type: str
        :param extension: Search files by given extension.
        :type extension: str
        :param url: Search by file URL.
        :type url: str
        :param is_usable_in_content: If `true`, shows files that have been marked to be used in new content. If `false`, shows files that should not be used in new content.
        :type is_usable_in_content: bool
        :param allows_anonymous_access: Search files by access. If `true`, will show only public files. If `false`, will show only private files.
        :type allows_anonymous_access: bool
        :param file_md5: Search files by a specific md5 hash.
        :type file_md5: str
        :param expires_at: Search files by exact expires time. Time must be epoch time in milliseconds.
        :type expires_at: datetime
        :param expires_at_lte: Search files by less than or equal to expires time. Can be used with `expiresAtGte` to create a range.
        :type expires_at_lte: datetime
        :param expires_at_gte: Search files by greater than or equal to expires time. Can be used with `expiresAtLte` to create a range.
        :type expires_at_gte: datetime
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CollectionResponseFile, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            "properties",
            "after",
            "before",
            "limit",
            "sort",
            "ids",
            "id_lte",
            "id_gte",
            "created_at",
            "created_at_lte",
            "created_at_gte",
            "updated_at",
            "updated_at_lte",
            "updated_at_gte",
            "name",
            "path",
            "parent_folder_ids",
            "size",
            "size_lte",
            "size_gte",
            "height",
            "height_lte",
            "height_gte",
            "width",
            "width_lte",
            "width_gte",
            "encoding",
            "type",
            "extension",
            "url",
            "is_usable_in_content",
            "allows_anonymous_access",
            "file_md5",
            "expires_at",
            "expires_at_lte",
            "expires_at_gte",
        ]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method do_search" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get("properties") is not None:  # noqa: E501
            query_params.append(("properties", local_var_params["properties"]))  # noqa: E501
            collection_formats["properties"] = "multi"  # noqa: E501
        if local_var_params.get("after") is not None:  # noqa: E501
            query_params.append(("after", local_var_params["after"]))  # noqa: E501
        if local_var_params.get("before") is not None:  # noqa: E501
            query_params.append(("before", local_var_params["before"]))  # noqa: E501
        if local_var_params.get("limit") is not None:  # noqa: E501
            query_params.append(("limit", local_var_params["limit"]))  # noqa: E501
        if local_var_params.get("sort") is not None:  # noqa: E501
            query_params.append(("sort", local_var_params["sort"]))  # noqa: E501
            collection_formats["sort"] = "multi"  # noqa: E501
        if local_var_params.get("ids") is not None:  # noqa: E501
            query_params.append(("ids", local_var_params["ids"]))  # noqa: E501
            collection_formats["ids"] = "multi"  # noqa: E501
        if local_var_params.get("id_lte") is not None:  # noqa: E501
            query_params.append(("idLte", local_var_params["id_lte"]))  # noqa: E501
        if local_var_params.get("id_gte") is not None:  # noqa: E501
            query_params.append(("idGte", local_var_params["id_gte"]))  # noqa: E501
        if local_var_params.get("created_at") is not None:  # noqa: E501
            query_params.append(("createdAt", local_var_params["created_at"]))  # noqa: E501
        if local_var_params.get("created_at_lte") is not None:  # noqa: E501
            query_params.append(("createdAtLte", local_var_params["created_at_lte"]))  # noqa: E501
        if local_var_params.get("created_at_gte") is not None:  # noqa: E501
            query_params.append(("createdAtGte", local_var_params["created_at_gte"]))  # noqa: E501
        if local_var_params.get("updated_at") is not None:  # noqa: E501
            query_params.append(("updatedAt", local_var_params["updated_at"]))  # noqa: E501
        if local_var_params.get("updated_at_lte") is not None:  # noqa: E501
            query_params.append(("updatedAtLte", local_var_params["updated_at_lte"]))  # noqa: E501
        if local_var_params.get("updated_at_gte") is not None:  # noqa: E501
            query_params.append(("updatedAtGte", local_var_params["updated_at_gte"]))  # noqa: E501
        if local_var_params.get("name") is not None:  # noqa: E501
            query_params.append(("name", local_var_params["name"]))  # noqa: E501
        if local_var_params.get("path") is not None:  # noqa: E501
            query_params.append(("path", local_var_params["path"]))  # noqa: E501
        if local_var_params.get("parent_folder_ids") is not None:  # noqa: E501
            query_params.append(("parentFolderIds", local_var_params["parent_folder_ids"]))  # noqa: E501
            collection_formats["parentFolderIds"] = "multi"  # noqa: E501
        if local_var_params.get("size") is not None:  # noqa: E501
            query_params.append(("size", local_var_params["size"]))  # noqa: E501
        if local_var_params.get("size_lte") is not None:  # noqa: E501
            query_params.append(("sizeLte", local_var_params["size_lte"]))  # noqa: E501
        if local_var_params.get("size_gte") is not None:  # noqa: E501
            query_params.append(("sizeGte", local_var_params["size_gte"]))  # noqa: E501
        if local_var_params.get("height") is not None:  # noqa: E501
            query_params.append(("height", local_var_params["height"]))  # noqa: E501
        if local_var_params.get("height_lte") is not None:  # noqa: E501
            query_params.append(("heightLte", local_var_params["height_lte"]))  # noqa: E501
        if local_var_params.get("height_gte") is not None:  # noqa: E501
            query_params.append(("heightGte", local_var_params["height_gte"]))  # noqa: E501
        if local_var_params.get("width") is not None:  # noqa: E501
            query_params.append(("width", local_var_params["width"]))  # noqa: E501
        if local_var_params.get("width_lte") is not None:  # noqa: E501
            query_params.append(("widthLte", local_var_params["width_lte"]))  # noqa: E501
        if local_var_params.get("width_gte") is not None:  # noqa: E501
            query_params.append(("widthGte", local_var_params["width_gte"]))  # noqa: E501
        if local_var_params.get("encoding") is not None:  # noqa: E501
            query_params.append(("encoding", local_var_params["encoding"]))  # noqa: E501
        if local_var_params.get("type") is not None:  # noqa: E501
            query_params.append(("type", local_var_params["type"]))  # noqa: E501
        if local_var_params.get("extension") is not None:  # noqa: E501
            query_params.append(("extension", local_var_params["extension"]))  # noqa: E501
        if local_var_params.get("url") is not None:  # noqa: E501
            query_params.append(("url", local_var_params["url"]))  # noqa: E501
        if local_var_params.get("is_usable_in_content") is not None:  # noqa: E501
            query_params.append(("isUsableInContent", local_var_params["is_usable_in_content"]))  # noqa: E501
        if local_var_params.get("allows_anonymous_access") is not None:  # noqa: E501
            query_params.append(("allowsAnonymousAccess", local_var_params["allows_anonymous_access"]))  # noqa: E501
        if local_var_params.get("file_md5") is not None:  # noqa: E501
            query_params.append(("fileMd5", local_var_params["file_md5"]))  # noqa: E501
        if local_var_params.get("expires_at") is not None:  # noqa: E501
            query_params.append(("expiresAt", local_var_params["expires_at"]))  # noqa: E501
        if local_var_params.get("expires_at_lte") is not None:  # noqa: E501
            query_params.append(("expiresAtLte", local_var_params["expires_at_lte"]))  # noqa: E501
        if local_var_params.get("expires_at_gte") is not None:  # noqa: E501
            query_params.append(("expiresAtGte", local_var_params["expires_at_gte"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "CollectionResponseFile",
        }

        return self.api_client.call_api(
            "/files/v3/files/search",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_by_id(self, file_id, **kwargs):  # noqa: E501
        """Retrieve file by ID  # noqa: E501

        Retrieve a file by its ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id(file_id, async_req=True)
        >>> result = thread.get()

        :param file_id: ID of the desired file. (required)
        :type file_id: str
        :param properties: null
        :type properties: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: File
        """
        kwargs["_return_http_data_only"] = True
        return self.get_by_id_with_http_info(file_id, **kwargs)  # noqa: E501

    def get_by_id_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Retrieve file by ID  # noqa: E501

        Retrieve a file by its ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param file_id: ID of the desired file. (required)
        :type file_id: str
        :param properties: null
        :type properties: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(File, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["file_id", "properties"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_by_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and local_var_params.get("file_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `get_by_id`")  # noqa: E501

        if self.api_client.client_side_validation and "file_id" in local_var_params and not re.search(r"\d+", local_var_params["file_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `file_id` when calling `get_by_id`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "file_id" in local_var_params:
            path_params["fileId"] = local_var_params["file_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("properties") is not None:  # noqa: E501
            query_params.append(("properties", local_var_params["properties"]))  # noqa: E501
            collection_formats["properties"] = "multi"  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "File",
        }

        return self.api_client.call_api(
            "/files/v3/files/{fileId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_metadata(self, path, **kwargs):  # noqa: E501
        """Retrieve file by path  # noqa: E501

        Retrieve a file by its path.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_metadata(path, async_req=True)
        >>> result = thread.get()

        :param path: The path of the file.  (required)
        :type path: str
        :param properties: Properties to return in the response.
        :type properties: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: FileStat
        """
        kwargs["_return_http_data_only"] = True
        return self.get_metadata_with_http_info(path, **kwargs)  # noqa: E501

    def get_metadata_with_http_info(self, path, **kwargs):  # noqa: E501
        """Retrieve file by path  # noqa: E501

        Retrieve a file by its path.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_metadata_with_http_info(path, async_req=True)
        >>> result = thread.get()

        :param path: The path of the file.  (required)
        :type path: str
        :param properties: Properties to return in the response.
        :type properties: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(FileStat, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["path", "properties"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_metadata" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'path' is set
        if self.api_client.client_side_validation and local_var_params.get("path") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `path` when calling `get_metadata`")  # noqa: E501

        if self.api_client.client_side_validation and "path" in local_var_params and not re.search(r".+", local_var_params["path"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `path` when calling `get_metadata`, must conform to the pattern `/.+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "path" in local_var_params:
            path_params["path"] = local_var_params["path"]  # noqa: E501

        query_params = []
        if local_var_params.get("properties") is not None:  # noqa: E501
            query_params.append(("properties", local_var_params["properties"]))  # noqa: E501
            collection_formats["properties"] = "multi"  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "FileStat",
        }

        return self.api_client.call_api(
            "/files/v3/files/stat/{path}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_signed_url(self, file_id, **kwargs):  # noqa: E501
        """Get signed URL to access private file  # noqa: E501

        Generates signed URL that allows temporary access to a private file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_signed_url(file_id, async_req=True)
        >>> result = thread.get()

        :param file_id: ID of file. (required)
        :type file_id: str
        :param size: For image files. This will resize the image to the desired size before sharing. Does not affect the original file, just the file served by this signed URL.
        :type size: str
        :param expiration_seconds: How long in seconds the link will provide access to the file.
        :type expiration_seconds: int
        :param upscale: If size is provided, this will upscale the image to fit the size dimensions.
        :type upscale: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SignedUrl
        """
        kwargs["_return_http_data_only"] = True
        return self.get_signed_url_with_http_info(file_id, **kwargs)  # noqa: E501

    def get_signed_url_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Get signed URL to access private file  # noqa: E501

        Generates signed URL that allows temporary access to a private file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_signed_url_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param file_id: ID of file. (required)
        :type file_id: str
        :param size: For image files. This will resize the image to the desired size before sharing. Does not affect the original file, just the file served by this signed URL.
        :type size: str
        :param expiration_seconds: How long in seconds the link will provide access to the file.
        :type expiration_seconds: int
        :param upscale: If size is provided, this will upscale the image to fit the size dimensions.
        :type upscale: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SignedUrl, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["file_id", "size", "expiration_seconds", "upscale"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_signed_url" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and local_var_params.get("file_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `get_signed_url`")  # noqa: E501

        if self.api_client.client_side_validation and "file_id" in local_var_params and not re.search(r"\d+", local_var_params["file_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `file_id` when calling `get_signed_url`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "file_id" in local_var_params:
            path_params["fileId"] = local_var_params["file_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("size") is not None:  # noqa: E501
            query_params.append(("size", local_var_params["size"]))  # noqa: E501
        if local_var_params.get("expiration_seconds") is not None:  # noqa: E501
            query_params.append(("expirationSeconds", local_var_params["expiration_seconds"]))  # noqa: E501
        if local_var_params.get("upscale") is not None:  # noqa: E501
            query_params.append(("upscale", local_var_params["upscale"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "SignedUrl",
        }

        return self.api_client.call_api(
            "/files/v3/files/{fileId}/signed-url",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def import_from_url(self, import_from_url_input, **kwargs):  # noqa: E501
        """Import file from URL  # noqa: E501

        Asynchronously imports the file at the given URL into the file manager.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.import_from_url(import_from_url_input, async_req=True)
        >>> result = thread.get()

        :param import_from_url_input: (required)
        :type import_from_url_input: ImportFromUrlInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ImportFromUrlTaskLocator
        """
        kwargs["_return_http_data_only"] = True
        return self.import_from_url_with_http_info(import_from_url_input, **kwargs)  # noqa: E501

    def import_from_url_with_http_info(self, import_from_url_input, **kwargs):  # noqa: E501
        """Import file from URL  # noqa: E501

        Asynchronously imports the file at the given URL into the file manager.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.import_from_url_with_http_info(import_from_url_input, async_req=True)
        >>> result = thread.get()

        :param import_from_url_input: (required)
        :type import_from_url_input: ImportFromUrlInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ImportFromUrlTaskLocator, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["import_from_url_input"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method import_from_url" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'import_from_url_input' is set
        if self.api_client.client_side_validation and local_var_params.get("import_from_url_input") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `import_from_url_input` when calling `import_from_url`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "import_from_url_input" in local_var_params:
            body_params = local_var_params["import_from_url_input"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            202: "ImportFromUrlTaskLocator",
        }

        return self.api_client.call_api(
            "/files/v3/files/import-from-url/async",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def replace(self, file_id, **kwargs):  # noqa: E501
        """Replace file  # noqa: E501

        Replace existing file data with new file data. Can be used to change image content without having to upload a new file and update all references.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.replace(file_id, async_req=True)
        >>> result = thread.get()

        :param file_id: ID of the desired file. (required)
        :type file_id: str
        :param file: File data that will replace existing file in the file manager.
        :type file: file
        :param charset_hunch: Character set of given file data.
        :type charset_hunch: str
        :param options: JSON string representing FileReplaceOptions. Includes options to set the access and expiresAt properties, which will automatically update when the file is replaced.
        :type options: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: File
        """
        kwargs["_return_http_data_only"] = True
        return self.replace_with_http_info(file_id, **kwargs)  # noqa: E501

    def replace_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Replace file  # noqa: E501

        Replace existing file data with new file data. Can be used to change image content without having to upload a new file and update all references.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.replace_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param file_id: ID of the desired file. (required)
        :type file_id: str
        :param file: File data that will replace existing file in the file manager.
        :type file: file
        :param charset_hunch: Character set of given file data.
        :type charset_hunch: str
        :param options: JSON string representing FileReplaceOptions. Includes options to set the access and expiresAt properties, which will automatically update when the file is replaced.
        :type options: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(File, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["file_id", "file", "charset_hunch", "options"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method replace" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and local_var_params.get("file_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `replace`")  # noqa: E501

        if self.api_client.client_side_validation and "file_id" in local_var_params and not re.search(r"\d+", local_var_params["file_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `file_id` when calling `replace`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "file_id" in local_var_params:
            path_params["fileId"] = local_var_params["file_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}
        if "file" in local_var_params:
            local_var_files["file"] = local_var_params["file"]  # noqa: E501
        if "charset_hunch" in local_var_params:
            form_params.append(("charsetHunch", local_var_params["charset_hunch"]))  # noqa: E501
        if "options" in local_var_params:
            form_params.append(("options", local_var_params["options"]))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["multipart/form-data"], "PUT", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "File",
        }

        return self.api_client.call_api(
            "/files/v3/files/{fileId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update_properties(self, file_id, file_update_input, **kwargs):  # noqa: E501
        """Update file properties  # noqa: E501

        Update properties of file by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_properties(file_id, file_update_input, async_req=True)
        >>> result = thread.get()

        :param file_id: ID of file to update (required)
        :type file_id: str
        :param file_update_input: (required)
        :type file_update_input: FileUpdateInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: File
        """
        kwargs["_return_http_data_only"] = True
        return self.update_properties_with_http_info(file_id, file_update_input, **kwargs)  # noqa: E501

    def update_properties_with_http_info(self, file_id, file_update_input, **kwargs):  # noqa: E501
        """Update file properties  # noqa: E501

        Update properties of file by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_properties_with_http_info(file_id, file_update_input, async_req=True)
        >>> result = thread.get()

        :param file_id: ID of file to update (required)
        :type file_id: str
        :param file_update_input: (required)
        :type file_update_input: FileUpdateInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(File, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["file_id", "file_update_input"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update_properties" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and local_var_params.get("file_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `update_properties`")  # noqa: E501
        # verify the required parameter 'file_update_input' is set
        if self.api_client.client_side_validation and local_var_params.get("file_update_input") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_update_input` when calling `update_properties`")  # noqa: E501

        if self.api_client.client_side_validation and "file_id" in local_var_params and not re.search(r"\d+", local_var_params["file_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `file_id` when calling `update_properties`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "file_id" in local_var_params:
            path_params["fileId"] = local_var_params["file_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "file_update_input" in local_var_params:
            body_params = local_var_params["file_update_input"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PATCH", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "File",
        }

        return self.api_client.call_api(
            "/files/v3/files/{fileId}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def upload(self, **kwargs):  # noqa: E501
        """Upload file  # noqa: E501

        Upload a single file with content specified in request body.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upload(async_req=True)
        >>> result = thread.get()

        :param file: File to be uploaded.
        :type file: file
        :param folder_id: Either 'folderId' or 'folderPath' is required. folderId is the ID of the folder the file will be uploaded to.
        :type folder_id: str
        :param folder_path: Either 'folderPath' or 'folderId' is required. This field represents the destination folder path for the uploaded file. If a path doesn't exist, the system will try to create one.
        :type folder_path: str
        :param file_name: Desired name for the uploaded file.
        :type file_name: str
        :param charset_hunch: Character set of the uploaded file.
        :type charset_hunch: str
        :param options: JSON string representing FileUploadOptions.
        :type options: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: File
        """
        kwargs["_return_http_data_only"] = True
        return self.upload_with_http_info(**kwargs)  # noqa: E501

    def upload_with_http_info(self, **kwargs):  # noqa: E501
        """Upload file  # noqa: E501

        Upload a single file with content specified in request body.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upload_with_http_info(async_req=True)
        >>> result = thread.get()

        :param file: File to be uploaded.
        :type file: file
        :param folder_id: Either 'folderId' or 'folderPath' is required. folderId is the ID of the folder the file will be uploaded to.
        :type folder_id: str
        :param folder_path: Either 'folderPath' or 'folderId' is required. This field represents the destination folder path for the uploaded file. If a path doesn't exist, the system will try to create one.
        :type folder_path: str
        :param file_name: Desired name for the uploaded file.
        :type file_name: str
        :param charset_hunch: Character set of the uploaded file.
        :type charset_hunch: str
        :param options: JSON string representing FileUploadOptions.
        :type options: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(File, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["file", "folder_id", "folder_path", "file_name", "charset_hunch", "options"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method upload" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}
        if "file" in local_var_params:
            local_var_files["file"] = local_var_params["file"]  # noqa: E501
        if "folder_id" in local_var_params:
            form_params.append(("folderId", local_var_params["folder_id"]))  # noqa: E501
        if "folder_path" in local_var_params:
            form_params.append(("folderPath", local_var_params["folder_path"]))  # noqa: E501
        if "file_name" in local_var_params:
            form_params.append(("fileName", local_var_params["file_name"]))  # noqa: E501
        if "charset_hunch" in local_var_params:
            form_params.append(("charsetHunch", local_var_params["charset_hunch"]))  # noqa: E501
        if "options" in local_var_params:
            form_params.append(("options", local_var_params["options"]))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["multipart/form-data"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            201: "File",
        }

        return self.api_client.call_api(
            "/files/v3/files",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

"""
    Timeline

    This feature allows an app to create and configure custom events that can show up in the timelines of certain CRM objects like contacts, companies, tickets, or deals. You'll find multiple use cases for this API in the sections below.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.timeline.configuration import Configuration


class CollectionResponseTimelineEventTemplateNoPaging(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"results": "list[TimelineEventTemplate]"}

    attribute_map = {"results": "results"}

    def __init__(self, results=None, local_vars_configuration=None):  # noqa: E501
        """CollectionResponseTimelineEventTemplateNoPaging - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._results = None
        self.discriminator = None

        self.results = results

    @property
    def results(self):
        """Gets the results of this CollectionResponseTimelineEventTemplateNoPaging.  # noqa: E501


        :return: The results of this CollectionResponseTimelineEventTemplateNoPaging.  # noqa: E501
        :rtype: list[TimelineEventTemplate]
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this CollectionResponseTimelineEventTemplateNoPaging.


        :param results: The results of this CollectionResponseTimelineEventTemplateNoPaging.  # noqa: E501
        :type results: list[TimelineEventTemplate]
        """
        if self.local_vars_configuration.client_side_validation and results is None:  # noqa: E501
            raise ValueError("Invalid value for `results`, must not be `None`")  # noqa: E501

        self._results = results

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CollectionResponseTimelineEventTemplateNoPaging):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CollectionResponseTimelineEventTemplateNoPaging):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Forms

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.forms.configuration import Configuration


class MultipleCheckboxesField(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "object_type_id": "str",
        "hidden": "bool",
        "name": "str",
        "options": "list[EnumeratedFieldOption]",
        "description": "str",
        "default_values": "list[str]",
        "dependent_fields": "list[DependentField]",
        "label": "str",
        "field_type": "str",
        "required": "bool",
    }

    attribute_map = {
        "object_type_id": "objectTypeId",
        "hidden": "hidden",
        "name": "name",
        "options": "options",
        "description": "description",
        "default_values": "defaultValues",
        "dependent_fields": "dependentFields",
        "label": "label",
        "field_type": "fieldType",
        "required": "required",
    }

    def __init__(
        self,
        object_type_id=None,
        hidden=None,
        name=None,
        options=None,
        description=None,
        default_values=None,
        dependent_fields=None,
        label=None,
        field_type="multiple_checkboxes",
        required=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """MultipleCheckboxesField - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._object_type_id = None
        self._hidden = None
        self._name = None
        self._options = None
        self._description = None
        self._default_values = None
        self._dependent_fields = None
        self._label = None
        self._field_type = None
        self._required = None
        self.discriminator = None

        self.object_type_id = object_type_id
        self.hidden = hidden
        self.name = name
        self.options = options
        if description is not None:
            self.description = description
        self.default_values = default_values
        self.dependent_fields = dependent_fields
        self.label = label
        self.field_type = field_type
        self.required = required

    @property
    def object_type_id(self):
        """Gets the object_type_id of this MultipleCheckboxesField.  # noqa: E501

        A unique ID for this field's CRM object type. For example a CONTACT field will have the object type ID 0-1.  # noqa: E501

        :return: The object_type_id of this MultipleCheckboxesField.  # noqa: E501
        :rtype: str
        """
        return self._object_type_id

    @object_type_id.setter
    def object_type_id(self, object_type_id):
        """Sets the object_type_id of this MultipleCheckboxesField.

        A unique ID for this field's CRM object type. For example a CONTACT field will have the object type ID 0-1.  # noqa: E501

        :param object_type_id: The object_type_id of this MultipleCheckboxesField.  # noqa: E501
        :type object_type_id: str
        """
        if self.local_vars_configuration.client_side_validation and object_type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `object_type_id`, must not be `None`")  # noqa: E501

        self._object_type_id = object_type_id

    @property
    def hidden(self):
        """Gets the hidden of this MultipleCheckboxesField.  # noqa: E501

        Whether a field should be hidden or not. Hidden fields won't appear on the form, but can be used to pass a value to a property without requiring the customer to fill it in.  # noqa: E501

        :return: The hidden of this MultipleCheckboxesField.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this MultipleCheckboxesField.

        Whether a field should be hidden or not. Hidden fields won't appear on the form, but can be used to pass a value to a property without requiring the customer to fill it in.  # noqa: E501

        :param hidden: The hidden of this MultipleCheckboxesField.  # noqa: E501
        :type hidden: bool
        """
        if self.local_vars_configuration.client_side_validation and hidden is None:  # noqa: E501
            raise ValueError("Invalid value for `hidden`, must not be `None`")  # noqa: E501

        self._hidden = hidden

    @property
    def name(self):
        """Gets the name of this MultipleCheckboxesField.  # noqa: E501

        The identifier of the field. In combination with the object type ID, it must be unique.  # noqa: E501

        :return: The name of this MultipleCheckboxesField.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MultipleCheckboxesField.

        The identifier of the field. In combination with the object type ID, it must be unique.  # noqa: E501

        :param name: The name of this MultipleCheckboxesField.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def options(self):
        """Gets the options of this MultipleCheckboxesField.  # noqa: E501

        The list of available choices for this field.  # noqa: E501

        :return: The options of this MultipleCheckboxesField.  # noqa: E501
        :rtype: list[EnumeratedFieldOption]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this MultipleCheckboxesField.

        The list of available choices for this field.  # noqa: E501

        :param options: The options of this MultipleCheckboxesField.  # noqa: E501
        :type options: list[EnumeratedFieldOption]
        """
        if self.local_vars_configuration.client_side_validation and options is None:  # noqa: E501
            raise ValueError("Invalid value for `options`, must not be `None`")  # noqa: E501

        self._options = options

    @property
    def description(self):
        """Gets the description of this MultipleCheckboxesField.  # noqa: E501

        Additional text helping the customer to complete the field.  # noqa: E501

        :return: The description of this MultipleCheckboxesField.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this MultipleCheckboxesField.

        Additional text helping the customer to complete the field.  # noqa: E501

        :param description: The description of this MultipleCheckboxesField.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def default_values(self):
        """Gets the default_values of this MultipleCheckboxesField.  # noqa: E501

        The values selected by default. Those values will be submitted unless the customer modifies them.  # noqa: E501

        :return: The default_values of this MultipleCheckboxesField.  # noqa: E501
        :rtype: list[str]
        """
        return self._default_values

    @default_values.setter
    def default_values(self, default_values):
        """Sets the default_values of this MultipleCheckboxesField.

        The values selected by default. Those values will be submitted unless the customer modifies them.  # noqa: E501

        :param default_values: The default_values of this MultipleCheckboxesField.  # noqa: E501
        :type default_values: list[str]
        """
        if self.local_vars_configuration.client_side_validation and default_values is None:  # noqa: E501
            raise ValueError("Invalid value for `default_values`, must not be `None`")  # noqa: E501

        self._default_values = default_values

    @property
    def dependent_fields(self):
        """Gets the dependent_fields of this MultipleCheckboxesField.  # noqa: E501

        A list of other fields to make visible based on the value filled in for this field.  # noqa: E501

        :return: The dependent_fields of this MultipleCheckboxesField.  # noqa: E501
        :rtype: list[DependentField]
        """
        return self._dependent_fields

    @dependent_fields.setter
    def dependent_fields(self, dependent_fields):
        """Sets the dependent_fields of this MultipleCheckboxesField.

        A list of other fields to make visible based on the value filled in for this field.  # noqa: E501

        :param dependent_fields: The dependent_fields of this MultipleCheckboxesField.  # noqa: E501
        :type dependent_fields: list[DependentField]
        """
        if self.local_vars_configuration.client_side_validation and dependent_fields is None:  # noqa: E501
            raise ValueError("Invalid value for `dependent_fields`, must not be `None`")  # noqa: E501

        self._dependent_fields = dependent_fields

    @property
    def label(self):
        """Gets the label of this MultipleCheckboxesField.  # noqa: E501

        The main label for the form field.  # noqa: E501

        :return: The label of this MultipleCheckboxesField.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this MultipleCheckboxesField.

        The main label for the form field.  # noqa: E501

        :param label: The label of this MultipleCheckboxesField.  # noqa: E501
        :type label: str
        """
        if self.local_vars_configuration.client_side_validation and label is None:  # noqa: E501
            raise ValueError("Invalid value for `label`, must not be `None`")  # noqa: E501

        self._label = label

    @property
    def field_type(self):
        """Gets the field_type of this MultipleCheckboxesField.  # noqa: E501

        Determines how the field will be displayed and validated.  # noqa: E501

        :return: The field_type of this MultipleCheckboxesField.  # noqa: E501
        :rtype: str
        """
        return self._field_type

    @field_type.setter
    def field_type(self, field_type):
        """Sets the field_type of this MultipleCheckboxesField.

        Determines how the field will be displayed and validated.  # noqa: E501

        :param field_type: The field_type of this MultipleCheckboxesField.  # noqa: E501
        :type field_type: str
        """
        if self.local_vars_configuration.client_side_validation and field_type is None:  # noqa: E501
            raise ValueError("Invalid value for `field_type`, must not be `None`")  # noqa: E501
        allowed_values = ["multiple_checkboxes"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and field_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `field_type` ({0}), must be one of {1}".format(field_type, allowed_values))  # noqa: E501

        self._field_type = field_type

    @property
    def required(self):
        """Gets the required of this MultipleCheckboxesField.  # noqa: E501

        Whether a value for this field is required when submitting the form.  # noqa: E501

        :return: The required of this MultipleCheckboxesField.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this MultipleCheckboxesField.

        Whether a value for this field is required when submitting the form.  # noqa: E501

        :param required: The required of this MultipleCheckboxesField.  # noqa: E501
        :type required: bool
        """
        if self.local_vars_configuration.client_side_validation and required is None:  # noqa: E501
            raise ValueError("Invalid value for `required`, must not be `None`")  # noqa: E501

        self._required = required

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MultipleCheckboxesField):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MultipleCheckboxesField):
            return True

        return self.to_dict() != other.to_dict()



from ...discovery_base import DiscoveryBase

class Discovery(DiscoveryBase):
    @property
    def authors(self):
        from .authors.discovery import Discovery as AuthorsDiscovery
        return AuthorsDiscovery(self.config)

    @property
    def blog_posts(self):
        from .blog_posts.discovery import Discovery as BlogPostsDiscovery
        return BlogPostsDiscovery(self.config)

    @property
    def tags(self):
        from .tags.discovery import Discovery as TagsDiscovery
        return TagsDiscovery(self.config)



# coding: utf-8

# flake8: noqa
"""
    CRM Calling Extensions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.crm.extensions.calling.models.channel_connection_settings_patch_request import ChannelConnectionSettingsPatchRequest
from hubspot.crm.extensions.calling.models.channel_connection_settings_request import ChannelConnectionSettingsRequest
from hubspot.crm.extensions.calling.models.channel_connection_settings_response import ChannelConnectionSettingsResponse
from hubspot.crm.extensions.calling.models.error import Error
from hubspot.crm.extensions.calling.models.error_detail import ErrorDetail
from hubspot.crm.extensions.calling.models.mark_recording_as_ready_request import MarkRecordingAsReadyRequest
from hubspot.crm.extensions.calling.models.recording_settings_patch_request import RecordingSettingsPatchRequest
from hubspot.crm.extensions.calling.models.recording_settings_request import RecordingSettingsRequest
from hubspot.crm.extensions.calling.models.recording_settings_response import RecordingSettingsResponse
from hubspot.crm.extensions.calling.models.settings_patch_request import SettingsPatchRequest
from hubspot.crm.extensions.calling.models.settings_request import SettingsRequest
from hubspot.crm.extensions.calling.models.settings_response import SettingsResponse



import hubspot.cms.source_code as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def content_api(self) -> api_client.ContentApi:
        return self._configure_api_client(api_client, "ContentApi")

    @property
    def extract_api(self) -> api_client.ExtractApi:
        return self._configure_api_client(api_client, "ExtractApi")

    @property
    def metadata_api(self) -> api_client.MetadataApi:
        return self._configure_api_client(api_client, "MetadataApi")

    @property
    def validation_api(self) -> api_client.ValidationApi:
        return self._configure_api_client(api_client, "ValidationApi")



# coding: utf-8

# flake8: noqa
"""
    Marketing Emails

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.marketing.emails.models.ab_test_create_request_v_next import AbTestCreateRequestVNext
from hubspot.marketing.emails.models.aggregate_email_statistics import AggregateEmailStatistics
from hubspot.marketing.emails.models.collection_response_with_total_email_statistic_interval_no_paging import CollectionResponseWithTotalEmailStatisticIntervalNoPaging
from hubspot.marketing.emails.models.collection_response_with_total_public_email_forward_paging import CollectionResponseWithTotalPublicEmailForwardPaging
from hubspot.marketing.emails.models.collection_response_with_total_version_public_email import CollectionResponseWithTotalVersionPublicEmail
from hubspot.marketing.emails.models.content_clone_request_v_next import ContentCloneRequestVNext
from hubspot.marketing.emails.models.email_create_request import EmailCreateRequest
from hubspot.marketing.emails.models.email_statistic_interval import EmailStatisticInterval
from hubspot.marketing.emails.models.email_statistics_data import EmailStatisticsData
from hubspot.marketing.emails.models.email_update_request import EmailUpdateRequest
from hubspot.marketing.emails.models.error import Error
from hubspot.marketing.emails.models.error_detail import ErrorDetail
from hubspot.marketing.emails.models.forward_paging import ForwardPaging
from hubspot.marketing.emails.models.interval import Interval
from hubspot.marketing.emails.models.next_page import NextPage
from hubspot.marketing.emails.models.paging import Paging
from hubspot.marketing.emails.models.previous_page import PreviousPage
from hubspot.marketing.emails.models.public_button_style_settings import PublicButtonStyleSettings
from hubspot.marketing.emails.models.public_divider_style_settings import PublicDividerStyleSettings
from hubspot.marketing.emails.models.public_email import PublicEmail
from hubspot.marketing.emails.models.public_email_content import PublicEmailContent
from hubspot.marketing.emails.models.public_email_from_details import PublicEmailFromDetails
from hubspot.marketing.emails.models.public_email_recipients import PublicEmailRecipients
from hubspot.marketing.emails.models.public_email_style_settings import PublicEmailStyleSettings
from hubspot.marketing.emails.models.public_email_subscription_details import PublicEmailSubscriptionDetails
from hubspot.marketing.emails.models.public_email_testing_details import PublicEmailTestingDetails
from hubspot.marketing.emails.models.public_email_to_details import PublicEmailToDetails
from hubspot.marketing.emails.models.public_font_style import PublicFontStyle
from hubspot.marketing.emails.models.public_rss_email_details import PublicRssEmailDetails
from hubspot.marketing.emails.models.public_webversion_details import PublicWebversionDetails
from hubspot.marketing.emails.models.version_public_email import VersionPublicEmail
from hubspot.marketing.emails.models.version_user import VersionUser



from ..discovery_base import DiscoveryBase

class Discovery(DiscoveryBase):
    @property
    def associations(self):
        from .associations.discovery import Discovery as AssociationsDiscovery
        return AssociationsDiscovery(self.config)

    @property
    def commerce(self):
        from .commerce.discovery import Discovery as CommerceDiscovery
        return CommerceDiscovery(self.config)

    @property
    def contacts(self):
        from .contacts.discovery import Discovery as ContactsDiscovery
        return ContactsDiscovery(self.config)

    @property
    def companies(self):
        from .companies.discovery import Discovery as CompaniesDiscovery
        return CompaniesDiscovery(self.config)

    @property
    def deals(self):
        from .deals.discovery import Discovery as DealsDiscovery
        return DealsDiscovery(self.config)

    @property
    def exports(self):
        from .exports.discovery import Discovery as ExportsDiscovery
        return ExportsDiscovery(self.config)

    @property
    def extensions(self):
        from .extensions.discovery import Discovery as ExtensionsDiscovery
        return ExtensionsDiscovery(self.config)

    @property
    def imports(self):
        from .imports.discovery import Discovery as ImportsDiscovery
        return ImportsDiscovery(self.config)

    @property
    def line_items(self):
        from .line_items.discovery import Discovery as LineItemsDiscovery
        return LineItemsDiscovery(self.config)

    @property
    def lists(self):
        from .lists.discovery import Discovery as ListsDiscovery
        return ListsDiscovery(self.config)

    @property
    def objects(self):
        from .objects.discovery import Discovery as ObjectsDiscovery
        return ObjectsDiscovery(self.config)

    @property
    def pipelines(self):
        from .pipelines.discovery import Discovery as PipelinesDiscovery
        return PipelinesDiscovery(self.config)

    @property
    def products(self):
        from .products.discovery import Discovery as ProductsDiscovery
        return ProductsDiscovery(self.config)

    @property
    def properties(self):
        from .properties.discovery import Discovery as PropertiesDiscovery
        return PropertiesDiscovery(self.config)

    @property
    def quotes(self):
        from .quotes.discovery import Discovery as QuotesDiscovery
        return QuotesDiscovery(self.config)

    @property
    def owners(self):
        from .owners.discovery import Discovery as OwnersDiscovery
        return OwnersDiscovery(self.config)

    @property
    def schemas(self):
        from .schemas.discovery import Discovery as SchemasDiscovery
        return SchemasDiscovery(self.config)

    @property
    def tickets(self):
        from .tickets.discovery import Discovery as TicketsDiscovery
        return TicketsDiscovery(self.config)

    @property
    def timeline(self):
        from .timeline.discovery import Discovery as TimelineDiscovery
        return TimelineDiscovery(self.config)



# coding: utf-8

"""
    Timeline

    This feature allows an app to create and configure custom events that can show up in the timelines of certain CRM objects like contacts, companies, tickets, or deals. You'll find multiple use cases for this API in the sections below.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.timeline.configuration import Configuration


class BatchResponseTimelineEventResponseWithErrors(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "completed_at": "datetime",
        "num_errors": "int",
        "requested_at": "datetime",
        "started_at": "datetime",
        "links": "dict[str, str]",
        "results": "list[TimelineEventResponse]",
        "errors": "list[StandardError]",
        "status": "str",
    }

    attribute_map = {
        "completed_at": "completedAt",
        "num_errors": "numErrors",
        "requested_at": "requestedAt",
        "started_at": "startedAt",
        "links": "links",
        "results": "results",
        "errors": "errors",
        "status": "status",
    }

    def __init__(self, completed_at=None, num_errors=None, requested_at=None, started_at=None, links=None, results=None, errors=None, status=None, local_vars_configuration=None):  # noqa: E501
        """BatchResponseTimelineEventResponseWithErrors - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._completed_at = None
        self._num_errors = None
        self._requested_at = None
        self._started_at = None
        self._links = None
        self._results = None
        self._errors = None
        self._status = None
        self.discriminator = None

        self.completed_at = completed_at
        if num_errors is not None:
            self.num_errors = num_errors
        if requested_at is not None:
            self.requested_at = requested_at
        self.started_at = started_at
        if links is not None:
            self.links = links
        self.results = results
        if errors is not None:
            self.errors = errors
        self.status = status

    @property
    def completed_at(self):
        """Gets the completed_at of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501


        :return: The completed_at of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :rtype: datetime
        """
        return self._completed_at

    @completed_at.setter
    def completed_at(self, completed_at):
        """Sets the completed_at of this BatchResponseTimelineEventResponseWithErrors.


        :param completed_at: The completed_at of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :type completed_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and completed_at is None:  # noqa: E501
            raise ValueError("Invalid value for `completed_at`, must not be `None`")  # noqa: E501

        self._completed_at = completed_at

    @property
    def num_errors(self):
        """Gets the num_errors of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501


        :return: The num_errors of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :rtype: int
        """
        return self._num_errors

    @num_errors.setter
    def num_errors(self, num_errors):
        """Sets the num_errors of this BatchResponseTimelineEventResponseWithErrors.


        :param num_errors: The num_errors of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :type num_errors: int
        """

        self._num_errors = num_errors

    @property
    def requested_at(self):
        """Gets the requested_at of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501


        :return: The requested_at of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :rtype: datetime
        """
        return self._requested_at

    @requested_at.setter
    def requested_at(self, requested_at):
        """Sets the requested_at of this BatchResponseTimelineEventResponseWithErrors.


        :param requested_at: The requested_at of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :type requested_at: datetime
        """

        self._requested_at = requested_at

    @property
    def started_at(self):
        """Gets the started_at of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501


        :return: The started_at of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this BatchResponseTimelineEventResponseWithErrors.


        :param started_at: The started_at of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :type started_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and started_at is None:  # noqa: E501
            raise ValueError("Invalid value for `started_at`, must not be `None`")  # noqa: E501

        self._started_at = started_at

    @property
    def links(self):
        """Gets the links of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501


        :return: The links of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this BatchResponseTimelineEventResponseWithErrors.


        :param links: The links of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :type links: dict[str, str]
        """

        self._links = links

    @property
    def results(self):
        """Gets the results of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501


        :return: The results of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :rtype: list[TimelineEventResponse]
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this BatchResponseTimelineEventResponseWithErrors.


        :param results: The results of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :type results: list[TimelineEventResponse]
        """
        if self.local_vars_configuration.client_side_validation and results is None:  # noqa: E501
            raise ValueError("Invalid value for `results`, must not be `None`")  # noqa: E501

        self._results = results

    @property
    def errors(self):
        """Gets the errors of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501


        :return: The errors of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :rtype: list[StandardError]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this BatchResponseTimelineEventResponseWithErrors.


        :param errors: The errors of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :type errors: list[StandardError]
        """

        self._errors = errors

    @property
    def status(self):
        """Gets the status of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501


        :return: The status of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BatchResponseTimelineEventResponseWithErrors.


        :param status: The status of this BatchResponseTimelineEventResponseWithErrors.  # noqa: E501
        :type status: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["PENDING", "PROCESSING", "CANCELED", "COMPLETE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `status` ({0}), must be one of {1}".format(status, allowed_values))  # noqa: E501

        self._status = status

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchResponseTimelineEventResponseWithErrors):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BatchResponseTimelineEventResponseWithErrors):
            return True

        return self.to_dict() != other.to_dict()



import base64
import hmac
import hashlib

from datetime import datetime, timezone, timedelta

from hubspot.exceptions import InvalidSignatureVersionError, InvalidSignatureTimestampError


class Signature:
    MAX_ALLOWED_TIMESTAMP = 300

    @staticmethod
    def _is_timestamp_valid(timestamp: str) -> bool:
        if timestamp is None:
            return False
        try:
            timestamp_float = float(timestamp)
            request_time = datetime.fromtimestamp(timestamp_float // 1000, tz=timezone.utc)
            current_time = datetime.now(timezone.utc)
            return current_time - request_time < timedelta(seconds=Signature.MAX_ALLOWED_TIMESTAMP)
        except (ValueError, OverflowError):
            return False

    @staticmethod
    def is_valid(
        signature: str,
        client_secret: str,
        request_body: str,
        http_uri: str = None,
        http_method: str = "POST",
        signature_version: str = "v2",
        timestamp: str = None
    ) -> bool:
        if signature_version == "v3":
            if timestamp is None or not Signature._is_timestamp_valid(timestamp):
                raise InvalidSignatureTimestampError(timestamp=timestamp)

        hashed_signature = Signature.get_signature(
            client_secret,
            request_body,
            signature_version,
            http_uri,
            http_method,
            timestamp
        )

        return hmac.compare_digest(hashed_signature, signature)

    @staticmethod
    def get_signature(
        client_secret: str,
        request_body: str,
        signature_version: str,
        http_uri: str = None,
        http_method: str = "POST",
        timestamp: str = None
    ) -> str:
        if signature_version == "v1":
            source_string = f"{client_secret}{request_body}"
            return hashlib.sha256(source_string.encode("utf-8")).hexdigest()
        elif signature_version == "v2":
            source_string = f"{client_secret}{http_method}{http_uri}{request_body}"
            return hashlib.sha256(source_string.encode("utf-8")).hexdigest()
        elif signature_version == "v3":
            source_string = f"{http_method}{http_uri}{request_body}{timestamp}"
            hashed_signature = base64.b64encode(
                hmac.new(
                    client_secret.encode("utf-8"),
                    msg=source_string.encode("utf-8"),
                    digestmod=hashlib.sha256
                ).digest()
            ).decode()
            return hashed_signature
        else:
            raise InvalidSignatureVersionError(signature_version=signature_version)



import hubspot.crm.associations as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def v4(self):
        from .v4.discovery import Discovery as v4Discovery
        return v4Discovery(self.config)

    @property
    def schema(self):
        from .schema.discovery import Discovery as schemaDiscovery
        return schemaDiscovery(self.config)

    @property
    def batch_api(self) -> api_client.BatchApi:
        return self._configure_api_client(api_client, "BatchApi")




# coding: utf-8

# flake8: noqa

"""
    CRM Associations Schema

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.associations.v4.schema.api.definition_configurations_api import DefinitionConfigurationsApi
from hubspot.crm.associations.v4.schema.api.definitions_api import DefinitionsApi

# import ApiClient
from hubspot.crm.associations.v4.schema.api_client import ApiClient
from hubspot.crm.associations.v4.schema.configuration import Configuration
from hubspot.crm.associations.v4.schema.exceptions import OpenApiException
from hubspot.crm.associations.v4.schema.exceptions import ApiTypeError
from hubspot.crm.associations.v4.schema.exceptions import ApiValueError
from hubspot.crm.associations.v4.schema.exceptions import ApiKeyError
from hubspot.crm.associations.v4.schema.exceptions import ApiAttributeError
from hubspot.crm.associations.v4.schema.exceptions import ApiException

# import models into sdk package
from hubspot.crm.associations.v4.schema.models.association_spec_with_label import AssociationSpecWithLabel
from hubspot.crm.associations.v4.schema.models.batch_input_public_association_definition_configuration_create_request import BatchInputPublicAssociationDefinitionConfigurationCreateRequest
from hubspot.crm.associations.v4.schema.models.batch_input_public_association_definition_configuration_update_request import BatchInputPublicAssociationDefinitionConfigurationUpdateRequest
from hubspot.crm.associations.v4.schema.models.batch_input_public_association_spec import BatchInputPublicAssociationSpec
from hubspot.crm.associations.v4.schema.models.batch_response_public_association_definition_configuration_update_result import BatchResponsePublicAssociationDefinitionConfigurationUpdateResult
from hubspot.crm.associations.v4.schema.models.batch_response_public_association_definition_configuration_update_result_with_errors import (
    BatchResponsePublicAssociationDefinitionConfigurationUpdateResultWithErrors,
)
from hubspot.crm.associations.v4.schema.models.batch_response_public_association_definition_user_configuration import BatchResponsePublicAssociationDefinitionUserConfiguration
from hubspot.crm.associations.v4.schema.models.batch_response_public_association_definition_user_configuration_with_errors import BatchResponsePublicAssociationDefinitionUserConfigurationWithErrors
from hubspot.crm.associations.v4.schema.models.collection_response_association_spec_with_label_no_paging import CollectionResponseAssociationSpecWithLabelNoPaging
from hubspot.crm.associations.v4.schema.models.collection_response_public_association_definition_user_configuration_no_paging import (
    CollectionResponsePublicAssociationDefinitionUserConfigurationNoPaging,
)
from hubspot.crm.associations.v4.schema.models.error import Error
from hubspot.crm.associations.v4.schema.models.error_detail import ErrorDetail
from hubspot.crm.associations.v4.schema.models.public_association_definition_configuration_create_request import PublicAssociationDefinitionConfigurationCreateRequest
from hubspot.crm.associations.v4.schema.models.public_association_definition_configuration_update_request import PublicAssociationDefinitionConfigurationUpdateRequest
from hubspot.crm.associations.v4.schema.models.public_association_definition_configuration_update_result import PublicAssociationDefinitionConfigurationUpdateResult
from hubspot.crm.associations.v4.schema.models.public_association_definition_create_request import PublicAssociationDefinitionCreateRequest
from hubspot.crm.associations.v4.schema.models.public_association_definition_update_request import PublicAssociationDefinitionUpdateRequest
from hubspot.crm.associations.v4.schema.models.public_association_definition_user_configuration import PublicAssociationDefinitionUserConfiguration
from hubspot.crm.associations.v4.schema.models.public_association_spec import PublicAssociationSpec
from hubspot.crm.associations.v4.schema.models.standard_error import StandardError



# coding: utf-8

# flake8: noqa

"""
    CRM Calling Extensions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.extensions.calling.api.channel_connection_settings_api import ChannelConnectionSettingsApi
from hubspot.crm.extensions.calling.api.recording_settings_api import RecordingSettingsApi
from hubspot.crm.extensions.calling.api.settings_api import SettingsApi

# import ApiClient
from hubspot.crm.extensions.calling.api_client import ApiClient
from hubspot.crm.extensions.calling.configuration import Configuration
from hubspot.crm.extensions.calling.exceptions import OpenApiException
from hubspot.crm.extensions.calling.exceptions import ApiTypeError
from hubspot.crm.extensions.calling.exceptions import ApiValueError
from hubspot.crm.extensions.calling.exceptions import ApiKeyError
from hubspot.crm.extensions.calling.exceptions import ApiAttributeError
from hubspot.crm.extensions.calling.exceptions import ApiException

# import models into sdk package
from hubspot.crm.extensions.calling.models.channel_connection_settings_patch_request import ChannelConnectionSettingsPatchRequest
from hubspot.crm.extensions.calling.models.channel_connection_settings_request import ChannelConnectionSettingsRequest
from hubspot.crm.extensions.calling.models.channel_connection_settings_response import ChannelConnectionSettingsResponse
from hubspot.crm.extensions.calling.models.error import Error
from hubspot.crm.extensions.calling.models.error_detail import ErrorDetail
from hubspot.crm.extensions.calling.models.mark_recording_as_ready_request import MarkRecordingAsReadyRequest
from hubspot.crm.extensions.calling.models.recording_settings_patch_request import RecordingSettingsPatchRequest
from hubspot.crm.extensions.calling.models.recording_settings_request import RecordingSettingsRequest
from hubspot.crm.extensions.calling.models.recording_settings_response import RecordingSettingsResponse
from hubspot.crm.extensions.calling.models.settings_patch_request import SettingsPatchRequest
from hubspot.crm.extensions.calling.models.settings_request import SettingsRequest
from hubspot.crm.extensions.calling.models.settings_response import SettingsResponse
